@@ -1,11 +1,11 @@
-"""ModelScope MCP Server"""
+"""ModelScope MCP Server."""
 
 from ._version import __version__
 from .settings import settings
 
 
 def main():
-    """Main entry point for ModelScope MCP Server"""
+    """Serve as the main entry point for ModelScope MCP Server."""
     from .cli import main as cli_main
 
     cli_main()
