@@ -1,3 +1,5 @@
+"""ModelScope MCP Server implementation."""
+
 from typing import cast
 
 from fastmcp import FastMCP
@@ -12,6 +14,8 @@ from fastmcp.utilities import logging
 from ._version import __version__
 from .settings import settings
 from .tools.aigc import register_aigc_tools
+from .tools.mcp import register_mcp_tools
+from .tools.model import register_model_tools
 from .tools.paper import register_paper_tools
 from .tools.user import register_user_tools
 
@@ -20,7 +24,6 @@ logger = logging.get_logger(__name__)
 
 def create_mcp_server() -> FastMCP:
     """Create and configure the MCP server with all ModelScope tools."""
-
     fastmcp_settings.log_level = cast(LOG_LEVEL, settings.log_level)
 
     mcp = FastMCP(
@@ -38,7 +41,9 @@ def create_mcp_server() -> FastMCP:
 
     # Register all tools
     register_user_tools(mcp)
-    register_aigc_tools(mcp)
+    register_model_tools(mcp)
     register_paper_tools(mcp)
+    register_mcp_tools(mcp)
+    register_aigc_tools(mcp)
 
     return mcp
