@@ -4,7 +4,8 @@ from pydantic import Field, field_validator
 from pydantic_settings import BaseSettings, SettingsConfigDict
 
 from .constants import (
-    DEFAULT_IMAGE_GENERATION_MODEL,
+    DEFAULT_IMAGE_TO_IMAGE_MODEL,
+    DEFAULT_TEXT_TO_IMAGE_MODEL,
     MODELSCOPE_API_ENDPOINT,
     MODELSCOPE_API_INFERENCE_ENDPOINT,
     MODELSCOPE_OPENAPI_ENDPOINT,
@@ -23,29 +24,28 @@ class Settings(BaseSettings):
     )
 
     # ModelScope API settings
-    api_token: str | None = Field(
-        default=None, description="ModelScope API token for authentication"
-    )
-
+    api_token: str | None = Field(default=None, description="ModelScope API token for authentication")
     api_base_url: str = Field(
         default=MODELSCOPE_API_ENDPOINT,
         description="Base URL for ModelScope API",
     )
-
     openapi_base_url: str = Field(
         default=MODELSCOPE_OPENAPI_ENDPOINT,
         description="Base URL for ModelScope OpenAPI",
     )
-
     api_inference_base_url: str = Field(
         default=MODELSCOPE_API_INFERENCE_ENDPOINT,
         description="Base URL for ModelScope API Inference",
     )
 
     # Default model settings
-    default_image_generation_model: str = Field(
-        default=DEFAULT_IMAGE_GENERATION_MODEL,
-        description="Default model for image generation",
+    default_text_to_image_model: str = Field(
+        default=DEFAULT_TEXT_TO_IMAGE_MODEL,
+        description="Default model for text-to-image generation",
+    )
+    default_image_to_image_model: str = Field(
+        default=DEFAULT_IMAGE_TO_IMAGE_MODEL,
+        description="Default model for image-to-image generation",
     )
 
     # Logging settings
@@ -75,6 +75,35 @@ class Settings(BaseSettings):
         """Check if API token is configured."""
         return self.api_token is not None and len(self.api_token) > 0
 
+    def show_settings(self) -> None:
+        """Display current configuration settings in a formatted way."""
+        print("=" * 60)
+        print("📋 Global Settings")
+        print("=" * 60)
+
+        # API Configuration
+        print("🔑 API Configuration:")
+        masked_token = (
+            self.api_token[:-8] + "********" if self.api_token and len(self.api_token) > 4 else "Not configured"
+        )
+        print(f"  • Token: {masked_token}")
+        print(f"  • Base URL: {self.api_base_url}")
+        print(f"  • OpenAPI URL: {self.openapi_base_url}")
+        print(f"  • Inference URL: {self.api_inference_base_url}")
+        print()
+
+        # Default Models
+        print("🤖 Default Models:")
+        print(f"  • Text-to-Image: {self.default_text_to_image_model}")
+        print(f"  • Image-to-Image: {self.default_image_to_image_model}")
+        print()
+
+        # System Settings
+        print("⚙️ System Settings:")
+        print(f"  • Log Level: {self.log_level}")
+        print("=" * 60)
+        print()
+
 
 # Global settings instance
 settings = Settings()
